Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(942)

Unified Diff: ui/views/win/hwnd_message_handler.h

Issue 133273020: Relanding this as this caused layout tests failures on Win7 due to the call to ShowScrollBars being… (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 6 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | ui/views/win/hwnd_message_handler.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/views/win/hwnd_message_handler.h
===================================================================
--- ui/views/win/hwnd_message_handler.h (revision 245191)
+++ ui/views/win/hwnd_message_handler.h (working copy)
@@ -542,9 +542,12 @@
// Generates touch-ids for touch-events.
ui::SequentialIDGenerator id_generator_;
- // Indicates if the window has the WS_VSCROLL and WS_HSCROLL styles set.
- bool scroll_styles_set_;
+ // Indicates if the window needs the WS_VSCROLL and WS_HSCROLL styles.
+ bool needs_scroll_styles_;
+ // Set to true if we are in the context of a sizing or moving operation.
+ bool in_size_move_loop_;
+
DISALLOW_COPY_AND_ASSIGN(HWNDMessageHandler);
};
« no previous file with comments | « no previous file | ui/views/win/hwnd_message_handler.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698